histore.archive package
=======================

.. automodule:: histore.archive
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   histore.archive.manager
   histore.archive.provenance
   histore.archive.serialize
   histore.archive.store

Submodules
----------

.. toctree::
   :maxdepth: 3

   histore.archive.base
   histore.archive.merge
   histore.archive.reader
   histore.archive.row
   histore.archive.schema
   histore.archive.snapshot
   histore.archive.timestamp
   histore.archive.value
   histore.archive.writer
